@@ -7,13 +7,7 @@
 #' The function [ti()] creates a [TuningInstanceBatchMultiCrit] and the function [tune()] creates an instance internally.
 #'
 #' @inherit TuningInstanceBatchSingleCrit details
-#'
-#' @section Resources:
-#' There are several sections about hyperparameter optimization in the [mlr3book](https://mlr3book.mlr-org.com).
-#'
-#'  * Learn about [multi-objective optimization](https://mlr3book.mlr-org.com/chapters/chapter5/advanced_tuning_methods_and_black_box_optimization.html#sec-multi-metrics-tuning).
-#'
-#' The [gallery](https://mlr-org.com/gallery-all-optimization.html) features a collection of case studies and demos about optimization.
+#' @inheritSection TuningInstanceBatchSingleCrit Resources
 #'
 #' @inheritSection ArchiveBatchTuning Analysis
 #'
@@ -90,6 +84,7 @@ TuningInstanceBatchMultiCrit = R6Class("TuningInstanceBatchMultiCrit",
       callbacks = NULL
       ) {
       learner = assert_learner(as_learner(learner, clone = TRUE))
+      callbacks = assert_batch_tuning_callbacks(as_callbacks(callbacks))
 
       # tune token and search space
       if (!is.null(search_space) && length(learner$param_set$get_values(type = "only_token"))) {
@@ -109,17 +104,16 @@ TuningInstanceBatchMultiCrit = R6Class("TuningInstanceBatchMultiCrit",
       sids = search_space$ids()
       internal_tune_ids = search_space$ids(any_tags = "internal_tuning")
 
-      # subset search space to primary hyperparameters
-      if (length(internal_tune_ids)) {
-        search_space = search_space$subset(setdiff(sids, internal_tune_ids))
-      }
-
       # get internal search space
       self$internal_search_space = if (is.null(internal_search_space)) {
         # We DO NOT subset the search space because there we might keep an extra_trafo which is not allowed
         # for the internal tuning search space
         if (length(internal_tune_ids)) {
-          learner$param_set$subset(internal_tune_ids)$search_space()
+          if (search_space_from_tokens) {
+            learner$param_set$subset(internal_tune_ids)$search_space()
+          } else {
+            search_space$subset(internal_tune_ids)
+          }
         }
       } else {
         if (length(internal_tune_ids)) {
@@ -128,6 +122,11 @@ TuningInstanceBatchMultiCrit = R6Class("TuningInstanceBatchMultiCrit",
         as_search_space(internal_search_space)
       }
 
+      # subset search space to primary hyperparameters
+      if (length(internal_tune_ids)) {
+        search_space = search_space$subset(setdiff(sids, internal_tune_ids))
+      }
+
       # set learner parameter values
       if (search_space_from_tokens) {
         learner$param_set$values = learner$param_set$get_values(type = "without_token")
@@ -191,26 +190,34 @@ TuningInstanceBatchMultiCrit = R6Class("TuningInstanceBatchMultiCrit",
       # workaround
       extra = extra %??% xydt
 
+      # assign for callbacks
+      private$.result_xdt = xdt
+      private$.result_ydt = ydt
+      private$.result_learner_param_vals = learner_param_vals
+      private$.result_extra = extra
+
+      call_back("on_tuning_result_begin", self$objective$callbacks, self$objective$context)
+
       # extract internal tuned values
-      if ("internal_tuned_values" %in% names(extra)) {
-        set(xdt, j = "internal_tuned_values", value = list(extra[["internal_tuned_values"]]))
+      if ("internal_tuned_values" %in% names(private$.result_extra)) {
+        set(private$.result_xdt, j = "internal_tuned_values", value = list(private$.result_extra[["internal_tuned_values"]]))
       }
 
       # set the column with the learner param_vals that were not optimized over but set implicitly
-      if (is.null(learner_param_vals)) {
-        learner_param_vals = self$objective$learner$param_set$values
-        if (length(learner_param_vals) == 0) learner_param_vals = list()
-        learner_param_vals = replicate(nrow(ydt), list(learner_param_vals))
+      if (is.null(private$.result_learner_param_vals)) {
+        private$.result_learner_param_vals = self$objective$learner$param_set$values
+        if (length(private$.result_learner_param_vals) == 0) private$.result_learner_param_vals = list()
+        private$.result_learner_param_vals = replicate(nrow(private$.result_ydt), list(private$.result_learner_param_vals))
       }
 
-      opt_x = transform_xdt_to_xss(xdt, self$search_space)
-      if (length(opt_x) == 0) opt_x = replicate(length(ydt), list())
-      learner_param_vals = Map(insert_named, learner_param_vals, opt_x)
+      opt_x = transform_xdt_to_xss(private$.result_xdt, self$search_space)
+      if (length(opt_x) == 0) opt_x = replicate(length(private$.result_ydt), list())
+      private$.result_learner_param_vals = Map(insert_named, private$.result_learner_param_vals, opt_x)
 
       # disable internal tuning
-      if (!is.null(xdt$internal_tuned_values)) {
+      if (!is.null(private$.result_xdt$internal_tuned_values)) {
         learner = self$objective$learner$clone(deep = TRUE)
-        learner_param_vals = pmap(list(learner_param_vals, xdt$internal_tuned_values), function(lpv, itv) {
+        private$.result_learner_param_vals = pmap(list(private$.result_learner_param_vals, private$.result_xdt$internal_tuned_values), function(lpv, itv) {
           values = insert_named(lpv, itv)
           learner$param_set$set_values(.values = values, .insert = FALSE)
           learner$param_set$disable_internal_tuning(self$internal_search_space$ids())
@@ -218,9 +225,9 @@ TuningInstanceBatchMultiCrit = R6Class("TuningInstanceBatchMultiCrit",
         })
       }
 
-      set(xdt, j = "learner_param_vals", value = list(learner_param_vals))
+      set(private$.result_xdt, j = "learner_param_vals", value = list(private$.result_learner_param_vals))
 
-      super$assign_result(xdt, ydt)
+      super$assign_result(private$.result_xdt, private$.result_ydt)
     }
   ),
 
@@ -234,6 +241,9 @@ TuningInstanceBatchMultiCrit = R6Class("TuningInstanceBatchMultiCrit",
   ),
 
   private = list(
+    # intermediate objects
+    .result_learner_param_vals = NULL,
+
     # initialize context for optimization
     .initialize_context = function(optimizer) {
       context = ContextBatchTuning$new(self, optimizer)
