@@ -33,17 +33,23 @@
 #' @section Resources:
 #' There are several sections about hyperparameter optimization in the [mlr3book](https://mlr3book.mlr-org.com).
 #'
-#'  * Getting started with [hyperparameter optimization](https://mlr3book.mlr-org.com/chapters/chapter4/hyperparameter_optimization.html).
-#'  * [Tune](https://mlr3book.mlr-org.com/chapters/chapter4/hyperparameter_optimization.html#sec-model-tuning) a simple classification tree on the Sonar data set.
-#'  * Learn about [tuning spaces](https://mlr3book.mlr-org.com/chapters/chapter4/hyperparameter_optimization.html#sec-defining-search-spaces).
+#' * Getting started with [hyperparameter optimization](https://mlr3book.mlr-org.com/chapters/chapter4/hyperparameter_optimization.html).
+#' * An overview of all tuners can be found on our [website](https://mlr-org.com/tuners.html).
+#' * [Tune](https://mlr3book.mlr-org.com/chapters/chapter4/hyperparameter_optimization.html#sec-model-tuning) a support vector machine on the Sonar data set.
+#' * Learn about [tuning spaces](https://mlr3book.mlr-org.com/chapters/chapter4/hyperparameter_optimization.html#sec-defining-search-spaces).
+#' * Estimate the model performance with [nested resampling](https://mlr3book.mlr-org.com/chapters/chapter4/hyperparameter_optimization.html#sec-nested-resampling).
+#' * Learn about [multi-objective optimization](https://mlr3book.mlr-org.com/chapters/chapter5/advanced_tuning_methods_and_black_box_optimization.html#sec-multi-metrics-tuning).
+#' * Simultaneously optimize hyperparameters and use [early stopping](https://mlr3book.mlr-org.com/chapters/chapter15/predsets_valid_inttune.html) with XGBoost.
+#' * [Automate](https://mlr3book.mlr-org.com/chapters/chapter4/hyperparameter_optimization.html#sec-autotuner) the tuning.
 #'
 #' The [gallery](https://mlr-org.com/gallery-all-optimization.html) features a collection of case studies and demos about optimization.
 #'
-#'  * Learn more advanced methods with the [practical tuning series](https://mlr-org.com/gallery/series/2021-03-09-practical-tuning-series-tune-a-support-vector-machine/).
-#'  * Simultaneously optimize hyperparameters and use [early stopping](https://mlr-org.com/gallery/optimization/2022-11-04-early-stopping-with-xgboost/) with XGBoost.
-#'  * Make us of proven [search space](https://mlr-org.com/gallery/optimization/2021-07-06-introduction-to-mlr3tuningspaces/).
-#'  * Learn about [hotstarting](https://mlr-org.com/gallery/optimization/2023-01-16-hotstart/) models.
-#'  * Run the [default hyperparameter configuration](https://mlr-org.com/gallery/optimization/2023-01-31-default-configuration/) of learners as a baseline.
+#' * Learn more advanced methods with the [Practical Tuning Series](https://mlr-org.com/gallery/series/2021-03-09-practical-tuning-series-tune-a-support-vector-machine/).
+#' * Learn about [hotstarting](https://mlr-org.com/gallery/optimization/2023-01-16-hotstart/) models.
+#' * Run the [default hyperparameter configuration](https://mlr-org.com/gallery/optimization/2023-01-31-default-configuration/) of learners as a baseline.
+#' * Use the [Hyperband](https://mlr-org.com/gallery/series/2023-01-15-hyperband-xgboost/) optimizer with different budget parameters.
+#'
+#' The [cheatsheet](https://cheatsheets.mlr-org.com/mlr3tuning.pdf) summarizes the most important functions of mlr3tuning.
 #'
 #' @section Extension Packages:
 #'
@@ -128,6 +134,7 @@ TuningInstanceBatchSingleCrit = R6Class("TuningInstanceBatchSingleCrit",
       callbacks = NULL
       ) {
       learner = assert_learner(as_learner(learner, clone = TRUE))
+      callbacks = assert_batch_tuning_callbacks(as_callbacks(callbacks))
 
       # tune token and search space
       if (!is.null(search_space) && length(learner$param_set$get_values(type = "only_token"))) {
@@ -147,17 +154,16 @@ TuningInstanceBatchSingleCrit = R6Class("TuningInstanceBatchSingleCrit",
       sids = search_space$ids()
       internal_tune_ids = search_space$ids(any_tags = "internal_tuning")
 
-      # subset search space to primary hyperparameters
-      if (length(internal_tune_ids)) {
-        search_space = search_space$subset(setdiff(sids, internal_tune_ids))
-      }
-
       # get internal search space
       self$internal_search_space = if (is.null(internal_search_space)) {
         # We DO NOT subset the search space because there we might keep an extra_trafo which is not allowed
         # for the internal tuning search space
         if (length(internal_tune_ids)) {
-          learner$param_set$subset(internal_tune_ids)$search_space()
+          if (search_space_from_tokens) {
+            learner$param_set$subset(internal_tune_ids)$search_space()
+          } else {
+            search_space$subset(internal_tune_ids)
+          }
         }
       } else {
         if (length(internal_tune_ids)) {
@@ -166,6 +172,11 @@ TuningInstanceBatchSingleCrit = R6Class("TuningInstanceBatchSingleCrit",
         as_search_space(internal_search_space)
       }
 
+      # subset search space to primary hyperparameters
+      if (length(internal_tune_ids)) {
+        search_space = search_space$subset(setdiff(sids, internal_tune_ids))
+      }
+
       # set learner parameter values
       if (search_space_from_tokens) {
         learner$param_set$values = learner$param_set$get_values(type = "without_token")
@@ -229,35 +240,43 @@ TuningInstanceBatchSingleCrit = R6Class("TuningInstanceBatchSingleCrit",
       # workaround
       extra = extra %??% xydt
 
+      # assign for callbacks
+      private$.result_xdt = xdt
+      private$.result_y = y
+      private$.result_learner_param_vals = learner_param_vals
+      private$.result_extra = extra
+
+      call_back("on_tuning_result_begin", self$objective$callbacks, self$objective$context)
+
       # set the column with the learner param_vals that were not optimized over but set implicitly
-      assert_list(learner_param_vals, null.ok = TRUE, names = "named")
+      assert_list(private$.result_learner_param_vals, null.ok = TRUE, names = "named")
 
       # extract internal tuned values
-      if ("internal_tuned_values" %in% names(extra)) {
-        set(xdt, j = "internal_tuned_values", value = list(extra[["internal_tuned_values"]]))
+      if ("internal_tuned_values" %in% names(private$.result_extra)) {
+        set(private$.result_xdt, j = "internal_tuned_values", value = list(private$.result_extra[["internal_tuned_values"]]))
       }
 
       # learner param values
-      if (is.null(learner_param_vals)) {
-        learner_param_vals = self$objective$learner$param_set$values
+      if (is.null(private$.result_learner_param_vals)) {
+        private$.result_learner_param_vals = self$objective$learner$param_set$values
       }
-      opt_x = unlist(transform_xdt_to_xss(xdt, self$search_space), recursive = FALSE)
-      learner_param_vals = insert_named(learner_param_vals, opt_x)
+      opt_x = unlist(transform_xdt_to_xss(private$.result_xdt, self$search_space), recursive = FALSE)
+      private$.result_learner_param_vals = insert_named(private$.result_learner_param_vals, opt_x)
 
       # disable internal tuning
-      if (!is.null(xdt$internal_tuned_values)) {
+      if (!is.null(private$.result_xdt$internal_tuned_values)) {
         learner = self$objective$learner$clone(deep = TRUE)
-        learner_param_vals = insert_named(learner_param_vals, xdt$internal_tuned_values[[1]])
-        learner$param_set$set_values(.values = learner_param_vals)
+        private$.result_learner_param_vals = insert_named(private$.result_learner_param_vals, private$.result_xdt$internal_tuned_values[[1]])
+        learner$param_set$set_values(.values = private$.result_learner_param_vals)
         learner$param_set$disable_internal_tuning(self$internal_search_space$ids())
-        learner_param_vals = learner$param_set$values
+        private$.result_learner_param_vals = learner$param_set$values
       }
 
       # maintain list column
-      if (length(learner_param_vals) < 2 | !nrow(xdt)) learner_param_vals = list(learner_param_vals)
+      if (length(private$.result_learner_param_vals) < 2 | !nrow(private$.result_xdt)) private$.result_learner_param_vals = list(private$.result_learner_param_vals)
 
-      set(xdt, j = "learner_param_vals", value = list(learner_param_vals))
-      super$assign_result(xdt, y)
+      set(private$.result_xdt, j = "learner_param_vals", value = list(private$.result_learner_param_vals))
+      super$assign_result(private$.result_xdt, private$.result_y)
     }
   ),
 
@@ -270,6 +289,9 @@ TuningInstanceBatchSingleCrit = R6Class("TuningInstanceBatchSingleCrit",
   ),
 
   private = list(
+    # intermediate objects
+    .result_learner_param_vals = NULL,
+
     # initialize context for optimization
     .initialize_context = function(optimizer) {
       context = ContextBatchTuning$new(self, optimizer)
