@@ -44,6 +44,7 @@ tnrs = function(.keys, ...) {
 #' @template param_resampling
 #' @template param_terminator
 #' @template param_search_space
+#' @template param_internal_search_space
 #' @template param_store_benchmark_result
 #' @template param_store_models
 #' @template param_check_values
@@ -61,6 +62,7 @@ ti = function(
   measures = NULL,
   terminator,
   search_space = NULL,
+  internal_search_space = NULL,
   store_benchmark_result = TRUE,
   store_models = FALSE,
   check_values = FALSE,
@@ -75,6 +77,7 @@ ti = function(
     measures,
     terminator = terminator,
     search_space = search_space,
+    internal_search_space = internal_search_space,
     store_benchmark_result = store_benchmark_result,
     store_models = store_models,
     check_values = check_values,
@@ -95,6 +98,7 @@ ti = function(
 #' @template param_resampling
 #' @template param_terminator
 #' @template param_search_space
+#' @template param_internal_search_space
 #' @template param_store_benchmark_result
 #' @template param_store_models
 #' @template param_check_values
@@ -113,6 +117,7 @@ ti_async = function(
   measures = NULL,
   terminator,
   search_space = NULL,
+  internal_search_space = NULL,
   store_benchmark_result = TRUE,
   store_models = FALSE,
   check_values = FALSE,
@@ -128,6 +133,7 @@ ti_async = function(
     measures,
     terminator = terminator,
     search_space = search_space,
+    internal_search_space = internal_search_space,
     store_benchmark_result = store_benchmark_result,
     store_models = store_models,
     check_values = check_values,
